import logger from '../logger';
import { FlagService } from '../services/flag.service';
describe('ConfFlag', () => {
    let flagService;
    let infoSpy;
    let setSpy;
    let infoResult;
    let configServiceSpy;
    beforeEach(() => {
        infoResult = [];
        infoSpy = spyOn(logger, 'info').and.callFake((...data) => {
            infoResult = [...infoResult, data];
        });
        setSpy = spyOn(logger, 'set').and.callFake(() => ({}));
        configServiceSpy = jasmine.createSpyObj('ConfigService', [
            'config',
            'separator',
            'getAlias',
            'setAlias',
            'save'
        ]);
        configServiceSpy.separator = '@';
        configServiceSpy.config.alias = {};
        configServiceSpy.defaultConfig = {
            options: {
                separator: '@'
            },
            alias: {}
        };
        configServiceSpy.getAlias.and.returnValue(undefined);
        configServiceSpy.setAlias.and.callFake(() => ({}));
        flagService = new FlagService(configServiceSpy, {});
        infoSpy.calls.reset();
    });
    it('should set separator', async () => {
        await flagService.run(['-c', '-s', '#']);
        expect(setSpy).toHaveBeenCalledWith('separator', configServiceSpy.separator);
    });
    it('should set separator to default without value', async () => {
        await flagService.run(['-c', '-s']);
        expect(setSpy).toHaveBeenCalledWith('separator', configServiceSpy.separator);
    });
    it('should set gist id', async () => {
        await flagService.run(['-c', '-g', 'test']);
        expect(setSpy).toHaveBeenCalledWith('gist', configServiceSpy.gistId);
    });
    it('should log error if no gist id is provided', async () => {
        await flagService.run(['-c', '-g']);
        expect(infoSpy).toHaveBeenCalledWith('must specify a gist id');
    });
    it('should set gist token', async () => {
        await flagService.run(['-c', '-t', 'test']);
        expect(setSpy).toHaveBeenCalledWith('token', configServiceSpy.token);
    });
    it('should log error if no token is provided', async () => {
        await flagService.run(['-c', '-t']);
        expect(infoSpy).toHaveBeenCalledWith(`must specify a token`);
    });
    it('should set shell', async () => {
        await flagService.run(['-c', '-sh']);
        expect(setSpy).toHaveBeenCalledWith('shell', configServiceSpy.shell);
    });
    it('should log error if invalid value provided for shell', async () => {
        await flagService.run(['-c', '-sh', 'test']);
        expect(infoSpy).toHaveBeenCalledWith(`invalid value for shell: 'test'`);
    });
    it('should show path', async () => {
        await flagService.run(['-c', '-p']);
        expect(infoSpy).toHaveBeenCalledWith(configServiceSpy.filePath);
    });
});
