import path from 'path';
import logger from '../logger.js';
import { Flag } from './flag.js';
import { toBool } from '../utils/to-bool.js';
export class SetFlag extends Flag {
    options = {};
    flag = {
        key: 'set',
        short: 's',
        desc: 'set an alias',
        run: (args) => this.setAlias(args)
    };
    mods = [
        {
            key: 'shell',
            short: 'sh',
            desc: 'enable shell mode',
            run: (args) => this.setShell(args)
        },
        {
            key: 'env',
            short: 'e',
            desc: 'add environment variables',
            run: (args) => this.setEnv(args)
        },
        {
            key: 'env-file',
            short: 'ef',
            desc: 'add environment variables file',
            run: (args) => this.setEnvFile(args)
        },
        {
            key: 'quote',
            short: 'q',
            desc: 'add quotes to command',
            run: (args) => this.setQuote(args)
        }
    ];
    setQuote(data) {
        const quote = toBool(data);
        if (quote === undefined) {
            logger.info(`invalid value for quote: '${data[0]}'`);
            return true;
        }
        this.options.quote = quote;
        logger.set('quote', this.options.quote);
    }
    setShell(data) {
        const shell = toBool(data);
        if (shell === undefined) {
            logger.info(`invalid value for shell: '${data[0]}'`);
            return true;
        }
        this.options.shell = shell;
        logger.set('shell', this.options.shell);
    }
    setEnv(data) {
        if (!data[0]) {
            logger.info(`invalid value for env`);
            return true;
        }
        logger.set('ENV variables', '');
        data.forEach((val) => {
            logger.info('\t', val);
            const [key, value] = val.split('=');
            this.options.env = {
                ...(this.options.env ?? {}),
                [key]: value
            };
        });
    }
    setEnvFile(data) {
        if (!data[0]) {
            logger.info(`invalid value for env-file`);
            return true;
        }
        this.options.envFile = path.resolve(data[0]);
        logger.set('ENV File', this.options.envFile);
    }
    setAlias(args) {
        const separator = this.confService.separator;
        const separatorIndex = args.findIndex((a) => a === separator);
        if (separatorIndex === -1) {
            logger.info(`invalid input, missing separator: '${separator}'`);
            return true;
        }
        const key = args[separatorIndex - 1];
        let command = args.slice(separatorIndex + 1);
        if (!key || command.length === 0) {
            logger.info(`invalid arguments passed: '${key || ''}' ${separator} '${command.join(' ')}'`);
            return true;
        }
        if (command.length === 1) {
            command = command[0].split(' ');
        }
        const alias = this.confService.getAlias(key);
        if (alias) {
            logger.info(`unset alias: ${key} ${separator} ${alias.command.join(' ')}`);
        }
        this.confService.setAlias(key, {
            options: this.options,
            command
        });
        logger.info(`set alias: ${key} ${separator} ${command.join(' ')}`);
    }
}
