import https from 'node:https';
import logger from '../logger.js';
export class GistService {
    configService;
    constructor(configService) {
        this.configService = configService;
    }
    baseUrl = `https://api.github.com/gists/`;
    async request(url, options, data) {
        return new Promise((resolve, reject) => {
            const hr = https
                .request(url, options, (res) => {
                if (res.statusCode !== 200) {
                    return reject(new Error(res.statusMessage));
                }
                res.setEncoding('utf8');
                const body = [];
                res.on('data', (data) => body.push(data));
                res.on('end', () => resolve(JSON.parse(body.join(''))));
            })
                .on('error', (err) => reject(err));
            if (data ?? false) {
                hr.write(JSON.stringify({
                    description: 'Alia Config',
                    files: {
                        [this.configService.fileName]: {
                            content: JSON.stringify(data, null, 2)
                        }
                    }
                }));
            }
            hr.end();
        });
    }
    async restore() {
        logger.info('Restore config from Gist...');
        const gistId = this.configService.gistId;
        let data = {};
        try {
            data = await this.request(`${this.baseUrl}${gistId}`, {
                method: 'GET',
                headers: { 'User-Agent': 'nodejs' }
            });
        }
        catch (e) {
            throw e;
        }
        const { updated_at, files } = data;
        logger.info(`Fetched: ${updated_at}`);
        const gistFile = files[this.configService.fileName];
        if (!gistFile) {
            throw new Error(`Gist must contain a file named '${this.configService.fileName}'`);
        }
        try {
            const aliaConfig = JSON.parse(gistFile.content);
            aliaConfig.meta = this.configService.meta;
            this.configService.save(aliaConfig);
            logger.info('...Done:', this.configService.filePath);
        }
        catch (e) {
            throw e;
        }
    }
    async backup() {
        logger.info('Backup local config to Gist...');
        const gistId = this.configService.gistId;
        const token = this.configService.token;
        const config = this.configService.config;
        config.meta = {};
        try {
            const { html_url } = await this.request(`${this.baseUrl}${gistId}`, {
                method: 'PATCH',
                headers: {
                    'User-Agent': 'nodejs',
                    Authorization: `token ${token}`
                }
            }, config);
            logger.info('...Done:', html_url);
        }
        catch (e) {
            throw e;
        }
    }
}
